@@ -16,7 +16,9 @@
  */
 package javax.mail.internet;
 
+@SuppressWarnings("unused") // Dummy implementation
 public class InternetAddress {
     public InternetAddress(String from) {
+        // Dummy implementation
     }
 }
