@@ -96,7 +96,11 @@ public interface Loader {
 
     /**
      * @return the reloadable flag for this Loader.
+     *
+     * @deprecated Use {@link Context#getReloadable()}. This method will be
+     *             removed in Tomcat 10.
      */
+    @Deprecated
     public boolean getReloadable();
 
 
@@ -104,7 +108,11 @@ public interface Loader {
      * Set the reloadable flag for this Loader.
      *
      * @param reloadable The new reloadable flag
+     *
+     * @deprecated Use {@link Context#setReloadable(boolean)}. This method will
+     *             be removed in Tomcat 10.
      */
+    @Deprecated
     public void setReloadable(boolean reloadable);
 
 
