@@ -36,7 +36,7 @@ import java.util.Set;
  * @author Craig R. McClanahan
  * @author Peter Donald
  */
-public interface Pipeline {
+public interface Pipeline extends Contained {
 
     /**
      * @return the Valve instance that has been distinguished as the basic
@@ -123,20 +123,6 @@ public interface Pipeline {
     public boolean isAsyncSupported();
 
 
-    /**
-     * @return the Container with which this Pipeline is associated.
-     */
-    public Container getContainer();
-
-
-    /**
-     * Set the Container with which this Pipeline is associated.
-     *
-     * @param container The new associated container
-     */
-    public void setContainer(Container container);
-
-
     /**
      * Identifies the Valves, if any, in this Pipeline that do not support
      * async.
