@@ -5,9 +5,9 @@
  * The ASF licenses this file to You under the Apache License, Version 2.0
  * (the "License"); you may not use this file except in compliance with
  * the License.  You may obtain a copy of the License at
- * 
+ *
  *      http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
  * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
@@ -21,28 +21,22 @@ import org.apache.catalina.ha.ClusterMessageBase;
 
 /**
  * Session cluster message
- * 
- * @author Filip Hanik
+ *
  * @author Peter Rossbach
  */
 public class SessionMessageImpl extends ClusterMessageBase implements SessionMessage {
-    
-    private static final long serialVersionUID = 1L;
+
+    private static final long serialVersionUID = 2L;
 
 
-    public SessionMessageImpl() {
-    }
-    
-    
     /*
-
      * Private serializable variables to keep the messages state
      */
-    private int mEvtType = -1;
-    private byte[] mSession;
-    private String mSessionID;
+    private final int mEvtType;
+    private final byte[] mSession;
+    private final String mSessionID;
 
-    private String mContextName;
+    private final String mContextName;
     private long serializationTimestamp;
     private boolean timestampSet = false ;
     private String uniqueId;
@@ -77,7 +71,7 @@ public class SessionMessageImpl extends ClusterMessageBase implements SessionMes
      * <B>EVT_ALL_SESSION_DATA</B><BR>
      *    Send complete serializes session list<BR>
      * <B>EVT_ALL_SESSION_TRANSFERCOMPLETE</B><BR>
-     *    send that all session state information are transfered
+     *    send that all session state information are transferred
      *    after GET_ALL_SESSION received from this sender.<BR>
      * <B>EVT_CHANGE_SESSION_ID</B><BR>
      *    send original sessionID and new sessionID.<BR>
@@ -118,7 +112,7 @@ public class SessionMessageImpl extends ClusterMessageBase implements SessionMes
      */
     @Override
     public String getSessionID(){ return mSessionID; }
-    
+
     /**
      * set message send time but only the first setting works (one shot)
      */
@@ -131,12 +125,12 @@ public class SessionMessageImpl extends ClusterMessageBase implements SessionMes
             }
         }
     }
-    
+
     @Override
     public long getTimestamp() { return serializationTimestamp;}
-    
+
     /**
-     * clear text event type name (for logging purpose only) 
+     * clear text event type name (for logging purpose only)
      * @return the event type in a string representation, useful for debugging
      */
     @Override
@@ -150,7 +144,7 @@ public class SessionMessageImpl extends ClusterMessageBase implements SessionMes
             case EVT_GET_ALL_SESSIONS : return "SESSION-GET-ALL";
             case EVT_SESSION_DELTA : return "SESSION-DELTA";
             case EVT_ALL_SESSION_DATA : return "ALL-SESSION-DATA";
-            case EVT_ALL_SESSION_TRANSFERCOMPLETE : return "SESSION-STATE-TRANSFERED";
+            case EVT_ALL_SESSION_TRANSFERCOMPLETE : return "SESSION-STATE-TRANSFERRED";
             case EVT_CHANGE_SESSION_ID : return "SESSION-ID-CHANGED";
             case EVT_ALL_SESSION_NOCONTEXTMANAGER : return "NO-CONTEXT-MANAGER";
             default : return "UNKNOWN-EVENT-TYPE";
@@ -161,15 +155,12 @@ public class SessionMessageImpl extends ClusterMessageBase implements SessionMes
     public String getContextName() {
        return mContextName;
     }
+
     @Override
     public String getUniqueId() {
         return uniqueId;
     }
-    @Override
-    public void setUniqueId(String uniqueId) {
-        this.uniqueId = uniqueId;
-    }
-    
+
     @Override
     public String toString() {
         return getEventTypeString() + "#" + getContextName() + "#" + getSessionID() ;
