@@ -348,13 +348,16 @@ public final class HTMLManagerServlet extends ManagerServlet {
 
         PrintWriter writer = response.getWriter();
 
-        // HTML Header Section
-        writer.print(Constants.HTML_HEADER_SECTION);
-
-        // Body Header Section
         Object[] args = new Object[2];
         args[0] = request.getContextPath();
         args[1] = smClient.getString("htmlManagerServlet.title");
+
+        // HTML Header Section
+        writer.print(MessageFormat.format(
+            Constants.HTML_HEADER_SECTION, args
+        ));
+
+        // Body Header Section
         writer.print(MessageFormat.format
                      (Constants.BODY_HEADER_SECTION, args));
 
@@ -440,10 +443,11 @@ public final class HTMLManagerServlet extends ManagerServlet {
                 StringBuilder tmp = new StringBuilder();
                 tmp.append("path=");
                 tmp.append(URLEncoder.DEFAULT.encode(displayPath, StandardCharsets.UTF_8));
-                if (ctxt.getWebappVersion().length() > 0) {
+                final String webappVersion = ctxt.getWebappVersion();
+                if (webappVersion != null && webappVersion.length() > 0) {
                     tmp.append("&version=");
                     tmp.append(URLEncoder.DEFAULT.encode(
-                            ctxt.getWebappVersion(), StandardCharsets.UTF_8));
+                            webappVersion, StandardCharsets.UTF_8));
                 }
                 String pathVersion = tmp.toString();
 
@@ -460,10 +464,10 @@ public final class HTMLManagerServlet extends ManagerServlet {
                         + URLEncoder.DEFAULT.encode(contextPath + "/", StandardCharsets.UTF_8)
                         + "\" " + Constants.REL_EXTERNAL + ">"
                         + Escape.htmlElementContent(displayPath) + "</a>";
-                if ("".equals(ctxt.getWebappVersion())) {
+                if (webappVersion == null || webappVersion.isEmpty()) {
                     args[1] = noVersion;
                 } else {
-                    args[1] = Escape.htmlElementContent(ctxt.getWebappVersion());
+                    args[1] = Escape.htmlElementContent(webappVersion);
                 }
                 if (ctxt.getDisplayName() == null) {
                     args[2] = "&nbsp;";
@@ -794,7 +798,7 @@ public final class HTMLManagerServlet extends ManagerServlet {
      */
     @Override
     public String getServletInfo() {
-        return "HTMLManagerServlet, Copyright (c) 1999-2020, The Apache Software Foundation";
+        return "HTMLManagerServlet, Copyright (c) 1999-2021, The Apache Software Foundation";
     }
 
     /**
@@ -896,8 +900,7 @@ public final class HTMLManagerServlet extends ManagerServlet {
                     Escape.htmlElementContent(cn.getDisplayName())));
         }
         Manager manager = ctxt.getManager();
-        List<Session> sessions = new ArrayList<>();
-        sessions.addAll(Arrays.asList(manager.findSessions()));
+        List<Session> sessions = new ArrayList<>(Arrays.asList(manager.findSessions()));
         if (manager instanceof DistributedManager && showProxySessions) {
             // Add dummy proxy sessions
             Set<String> sessionIds =
@@ -954,7 +957,7 @@ public final class HTMLManagerServlet extends ManagerServlet {
                     orderBy = "DESC";
                 }
                 try {
-                    Collections.sort(sessions, comparator);
+                    sessions.sort(comparator);
                 } catch (IllegalStateException ise) {
                     // at least 1 of the sessions is invalidated
                     req.setAttribute(APPLICATION_ERROR, "Can't sort session list: one session is invalidated");
@@ -1016,10 +1019,9 @@ public final class HTMLManagerServlet extends ManagerServlet {
             return 0;
         }
         int nbAffectedSessions = 0;
-        for (int i = 0; i < sessionIds.length; ++i) {
-            String sessionId = sessionIds[i];
+        for (String sessionId : sessionIds) {
             HttpSession session =
-                getSessionForNameAndId(cn, sessionId, smClient).getSession();
+                    getSessionForNameAndId(cn, sessionId, smClient).getSession();
             if (null == session) {
                 // Shouldn't happen, but let's play nice...
                 if (debug >= 1) {
