@@ -67,6 +67,7 @@ import org.apache.coyote.http11.AbstractHttp11Protocol;
 import org.apache.tomcat.util.Diagnostics;
 import org.apache.tomcat.util.ExceptionUtils;
 import org.apache.tomcat.util.IntrospectionUtils;
+import org.apache.tomcat.util.buf.StringUtils;
 import org.apache.tomcat.util.modeler.Registry;
 import org.apache.tomcat.util.net.SSLContext;
 import org.apache.tomcat.util.net.SSLHostConfig;
@@ -553,7 +554,7 @@ public class ManagerServlet extends HttpServlet implements ContainerServlet {
                         smClient.getString("managerServlet.findleaksList"));
             }
             for (String result : results) {
-                if ("".equals(result)) {
+                if (result.isEmpty()) {
                     result = "/";
                 }
                 writer.println(result);
@@ -578,6 +579,8 @@ public class ManagerServlet extends HttpServlet implements ContainerServlet {
                     } else {
                         SSLHostConfig[] sslHostConfigs = http11Protoocol.findSslHostConfigs();
                         for (SSLHostConfig sslHostConfig : sslHostConfigs) {
+                            // tlsHostName is as provided by the user so use a case insensitive
+                            // comparison as host names are case insensitive.
                             if (sslHostConfig.getHostName().equalsIgnoreCase(tlsHostName)) {
                                 found = true;
                                 http11Protoocol.reloadSslHostConfig(tlsHostName);
@@ -1074,19 +1077,21 @@ public class ManagerServlet extends HttpServlet implements ContainerServlet {
                 String displayPath = context.getPath();
                 if (displayPath.equals(""))
                     displayPath = "/";
+                List<String> parts = null;
                 if (context.getState().isAvailable()) {
-                    writer.println(smClient.getString("managerServlet.listitem",
+                    parts = Arrays.asList(
                             displayPath,
                             "running",
                             "" + context.getManager().findSessions().length,
-                            context.getDocBase()));
+                            context.getDocBase());
                 } else {
-                    writer.println(smClient.getString("managerServlet.listitem",
+                    parts = Arrays.asList(
                             displayPath,
                             "stopped",
                             "0",
-                            context.getDocBase()));
+                            context.getDocBase());
                 }
+                writer.println(StringUtils.join(parts, ':'));
             }
         }
     }
