@@ -394,7 +394,7 @@ public class HostManagerServlet
                         "hostManagerServlet.configBaseCreateFail", name));
                 return;
             }
-            try (InputStream is = getServletContext().getResourceAsStream("/manager.xml")) {
+            try (InputStream is = getServletContext().getResourceAsStream("/WEB-INF/manager.xml")) {
                 Path dest = (new File(configBaseFile, "manager.xml")).toPath();
                 Files.copy(is, dest);
             } catch (IOException e) {
@@ -410,7 +410,7 @@ public class HostManagerServlet
         host.addLifecycleListener(new HostConfig());
 
         // Add host aliases
-        if ((aliases != null) && !("".equals(aliases))) {
+        if ((aliases != null) && !aliases.isEmpty()) {
             StringTokenizer tok = new StringTokenizer(aliases, ", ");
             while (tok.hasMoreTokens()) {
                 host.addAlias(tok.nextToken());
@@ -518,12 +518,11 @@ public class HostManagerServlet
         writer.println(smClient.getString("hostManagerServlet.listed",
                 engine.getName()));
         Container[] hosts = engine.findChildren();
-        for (int i = 0; i < hosts.length; i++) {
-            Host host = (Host) hosts[i];
+        for (Container container : hosts) {
+            Host host = (Host) container;
             String name = host.getName();
             String[] aliases = host.findAliases();
-            writer.println(smClient.getString("hostManagerServlet.listitem",
-                    name, StringUtils.join(aliases)));
+            writer.println(String.format("[%s]:[%s]", name, StringUtils.join(aliases)));
         }
     }
 
