@@ -38,7 +38,6 @@ import org.apache.catalina.core.StandardHost;
 import org.apache.catalina.core.StandardService;
 import org.apache.catalina.loader.WebappLoader;
 import org.apache.catalina.realm.DataSourceRealm;
-import org.apache.catalina.realm.JDBCRealm;
 import org.apache.catalina.realm.JNDIRealm;
 import org.apache.catalina.realm.MemoryRealm;
 import org.apache.catalina.realm.UserDatabaseRealm;
@@ -334,13 +333,17 @@ public class MBeanFactory {
      * @return the object name of the created realm
      *
      * @exception Exception if an MBean cannot be created or registered
+     *
+     * @deprecated This method will be removed in Tomcat 10. Use a
+     *             DataSourceRealm instead.
      */
+    @Deprecated
     public String createJDBCRealm(String parent, String driverName,
         String connectionName, String connectionPassword, String connectionURL)
         throws Exception {
 
         // Create a new JDBCRealm instance
-        JDBCRealm realm = new JDBCRealm();
+        org.apache.catalina.realm.JDBCRealm realm = new org.apache.catalina.realm.JDBCRealm();
         realm.setDriverName(driverName);
         realm.setConnectionName(connectionName);
         realm.setConnectionPassword(connectionPassword);
@@ -469,7 +472,6 @@ public class MBeanFactory {
 
         // Return the corresponding MBean name
         return context.getObjectName().toString();
-
     }
 
 
@@ -765,7 +767,6 @@ public class MBeanFactory {
            }
 
         }
-
     }
 
 
