@@ -149,10 +149,11 @@ public final class SecurityClassLoad {
         loader.loadClass(basePackage + "CoyoteInputStream$PrivilegedRead");
         loader.loadClass(basePackage + "CoyoteInputStream$PrivilegedReadArray");
         loader.loadClass(basePackage + "CoyoteInputStream$PrivilegedReadBuffer");
+        loader.loadClass(basePackage + "CoyoteOutputStream");
         loader.loadClass(basePackage + "InputBuffer$PrivilegedCreateConverter");
         loader.loadClass(basePackage + "Response$PrivilegedDoIsEncodable");
         loader.loadClass(basePackage + "Response$PrivilegedGenerateCookieString");
-        loader.loadClass(basePackage + "Response$PrivilgedEncodeUrl");
+        loader.loadClass(basePackage + "Response$PrivilegedEncodeUrl");
     }
 
 
