@@ -21,7 +21,6 @@ import java.nio.charset.StandardCharsets;
 import java.util.Collection;
 import java.util.Date;
 import java.util.HashSet;
-import java.util.Iterator;
 import java.util.Locale;
 import java.util.Set;
 import java.util.TimeZone;
@@ -127,13 +126,7 @@ public class SSIMediator {
         variableNames.add("LAST_MODIFIED");
         ssiExternalResolver.addVariableNames(variableNames);
         //Remove any variables that are reserved by this class
-        Iterator<String> iter = variableNames.iterator();
-        while (iter.hasNext()) {
-            String name = iter.next();
-            if (isNameReserved(name)) {
-                iter.remove();
-            }
-        }
+        variableNames.removeIf(this::isNameReserved);
         return variableNames;
     }
 
