@@ -157,12 +157,12 @@ public class SSIServlet extends HttpServlet {
         // (the "toUpperCase()" avoids problems on Windows systems)
         if (path == null || path.toUpperCase(Locale.ENGLISH).startsWith("/WEB-INF")
                 || path.toUpperCase(Locale.ENGLISH).startsWith("/META-INF")) {
-            res.sendError(HttpServletResponse.SC_NOT_FOUND, path);
+            res.sendError(HttpServletResponse.SC_NOT_FOUND);
             return;
         }
         URL resource = servletContext.getResource(path);
         if (resource == null) {
-            res.sendError(HttpServletResponse.SC_NOT_FOUND, path);
+            res.sendError(HttpServletResponse.SC_NOT_FOUND);
             return;
         }
         String resourceMimeType = servletContext.getMimeType(path);
@@ -221,4 +221,4 @@ public class SSIServlet extends HttpServlet {
         }
         bufferedReader.close();
     }
-}
\ No newline at end of file
+}
