@@ -48,4 +48,16 @@ public final class Constants {
      * @see Tomcat
      */
     public static final String NoDefaultWebXml = "org/apache/catalina/startup/NO_DEFAULT_XML";
+
+    /**
+     * Name of the system property containing
+     * the tomcat product installation path
+     */
+    public static final String CATALINA_HOME_PROP = "catalina.home";
+
+    /**
+     * Name of the system property containing
+     * the tomcat instance installation path
+     */
+    public static final String CATALINA_BASE_PROP = "catalina.base";
 }
