@@ -822,4 +822,16 @@ public class FailedContext extends LifecycleMBeanBase implements Context {
     public void setCreateUploadTargets(boolean createUploadTargets) { /* NO-OP */}
     @Override
     public boolean getCreateUploadTargets() { return false; }
+
+    @Override
+    public boolean isParallelAnnotationScanning() { return false; }
+    @Override
+    public void setParallelAnnotationScanning(boolean parallelAnnotationScanning) {}
+
+    @Override
+    public boolean getUseBloomFilterForArchives() { return false; }
+
+    @Override
+    public void setUseBloomFilterForArchives(boolean useBloomFilterForArchives) {}
+
 }
\ No newline at end of file
