@@ -338,22 +338,22 @@ public class StandardContextSF extends StoreFactoryBase {
         String tomcatwebxml = "WEB-INF/tomcat-web.xml";
 
         List<String> resource = new ArrayList<>();
-        for (int i = 0; i < wresources.length; i++) {
-            if (wresources[i].equals(confContext))
+        for (String wresource : wresources) {
+            if (wresource.equals(confContext))
                 continue;
-            if (wresources[i].equals(confWeb))
+            if (wresource.equals(confWeb))
                 continue;
-            if (wresources[i].equals(confHostDefault))
+            if (wresource.equals(confHostDefault))
                 continue;
-            if (wresources[i].equals(configFile))
+            if (wresource.equals(configFile))
                 continue;
-            if (wresources[i].equals(webxml))
+            if (wresource.equals(webxml))
                 continue;
-            if (wresources[i].equals(tomcatwebxml))
+            if (wresource.equals(tomcatwebxml))
                 continue;
-            resource.add(wresources[i]);
+            resource.add(wresource);
         }
-        return resource.toArray(new String[resource.size()]);
+        return resource.toArray(new String[0]);
     }
 
 }
