@@ -78,9 +78,9 @@ public class StandardHostSF extends StoreFactoryBase {
             Valve valves[] = host.getPipeline().getValves();
             if(valves != null && valves.length > 0 ) {
                 List<Valve> hostValves = new ArrayList<>() ;
-                for(int i = 0 ; i < valves.length ; i++ ) {
-                    if(!( valves[i] instanceof ClusterValve))
-                        hostValves.add(valves[i]);
+                for (Valve valve : valves) {
+                    if (!(valve instanceof ClusterValve))
+                        hostValves.add(valve);
                 }
                 storeElementArray(aWriter, indent, hostValves.toArray());
             }
