@@ -5,9 +5,9 @@
  * The ASF licenses this file to You under the Apache License, Version 2.0
  * (the "License"); you may not use this file except in compliance with
  * the License.  You may obtain a copy of the License at
- * 
+ *
  *      http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
  * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
@@ -22,8 +22,6 @@ import java.util.Iterator;
  * Channel interface
  * A managed channel interface gives you access to the components of the channels
  * such as senders, receivers, interceptors etc for configurations purposes
- * @author Filip Hanik
- *
  */
 public interface ManagedChannel extends Channel {
 
@@ -40,7 +38,7 @@ public interface ManagedChannel extends Channel {
      * @see ChannelReceiver
      */
     public void setChannelReceiver(ChannelReceiver receiver);
-    
+
     /**
      * Sets the membership service
      * @param service MembershipService
@@ -54,14 +52,14 @@ public interface ManagedChannel extends Channel {
      * @see ChannelSender
      */
     public ChannelSender getChannelSender();
-    
+
     /**
      * returns the channel receiver
      * @return ChannelReceiver
      * @see ChannelReceiver
      */
     public ChannelReceiver getChannelReceiver();
-    
+
     /**
      * Returns the membership service
      * @return MembershipService
@@ -74,5 +72,5 @@ public interface ManagedChannel extends Channel {
      * @return Iterator
      * @see Channel#addInterceptor(ChannelInterceptor)
      */
-    public Iterator getInterceptors();
+    public Iterator<ChannelInterceptor> getInterceptors();
 }
