@@ -88,9 +88,9 @@ public class ParallelNioSender extends AbstractSender implements MultiPointSende
                         if ( x instanceof ChannelException ) cx = (ChannelException)x;
                         else cx = new ChannelException(sm.getString("parallelNioSender.send.failed"), x);
                     }
-                    for (int i=0; i<senders.length; i++ ) {
-                        if (!senders[i].isComplete()) {
-                            cx.addFaultyMember(senders[i].getDestination(),x);
+                    for (NioSender sender : senders) {
+                        if (!sender.isComplete()) {
+                            cx.addFaultyMember(sender.getDestination(), x);
                         }
                     }
                     throw cx;
@@ -105,9 +105,9 @@ public class ParallelNioSender extends AbstractSender implements MultiPointSende
                     cx = new ChannelException(sm.getString("parallelNioSender.operation.timedout",
                             Long.toString(getTimeout())));
                 }
-                for (int i=0; i<senders.length; i++ ) {
-                    if (!senders[i].isComplete()) {
-                        cx.addFaultyMember(senders[i].getDestination(),cxtimeout);
+                for (NioSender sender : senders) {
+                    if (!sender.isComplete()) {
+                        cx.addFaultyMember(sender.getDestination(), cxtimeout);
                     }
                 }
                 throw cx;
@@ -232,12 +232,12 @@ public class ParallelNioSender extends AbstractSender implements MultiPointSende
 
     private void connect(NioSender[] senders) throws ChannelException {
         ChannelException x = null;
-        for (int i=0; i<senders.length; i++ ) {
+        for (NioSender sender : senders) {
             try {
-                senders[i].connect();
-            }catch ( IOException io ) {
-                if ( x==null ) x = new ChannelException(io);
-                x.addFaultyMember(senders[i].getDestination(),io);
+                sender.connect();
+            } catch (IOException io) {
+                if (x == null) x = new ChannelException(io);
+                x.addFaultyMember(sender.getDestination(), io);
             }
         }
         if ( x != null ) throw x;
@@ -245,12 +245,12 @@ public class ParallelNioSender extends AbstractSender implements MultiPointSende
 
     private void setData(NioSender[] senders, byte[] data) throws ChannelException {
         ChannelException x = null;
-        for (int i=0; i<senders.length; i++ ) {
+        for (NioSender sender : senders) {
             try {
-                senders[i].setMessage(data);
-            }catch ( IOException io ) {
-                if ( x==null ) x = new ChannelException(io);
-                x.addFaultyMember(senders[i].getDestination(),io);
+                sender.setMessage(data);
+            } catch (IOException io) {
+                if (x == null) x = new ChannelException(io);
+                x.addFaultyMember(sender.getDestination(), io);
             }
         }
         if ( x != null ) throw x;
@@ -293,14 +293,14 @@ public class ParallelNioSender extends AbstractSender implements MultiPointSende
     private synchronized void close() throws ChannelException  {
         ChannelException x = null;
         Object[] members = nioSenders.keySet().toArray();
-        for (int i=0; i<members.length; i++ ) {
-            Member mbr = (Member)members[i];
+        for (Object member : members) {
+            Member mbr = (Member) member;
             try {
                 NioSender sender = nioSenders.get(mbr);
                 sender.disconnect();
-            }catch ( Exception e ) {
-                if ( x == null ) x = new ChannelException(e);
-                x.addFaultyMember(mbr,e);
+            } catch (Exception e) {
+                if (x == null) x = new ChannelException(e);
+                x.addFaultyMember(mbr, e);
             }
             nioSenders.remove(mbr);
         }
