@@ -23,6 +23,7 @@ import java.util.Locale;
 import java.util.Properties;
 
 import org.apache.tomcat.util.ExceptionUtils;
+import org.apache.tomcat.util.compat.JreCompat;
 
 
 
@@ -69,11 +70,15 @@ public class CharsetMapper {
      *  resource could not be loaded for any reason.
      */
     public CharsetMapper(String name) {
-        try (InputStream stream = this.getClass().getResourceAsStream(name)) {
-            map.load(stream);
-        } catch (Throwable t) {
-            ExceptionUtils.handleThrowable(t);
-            throw new IllegalArgumentException(t.toString());
+        if (JreCompat.isGraalAvailable()) {
+            map.put("en", "ISO-8859-1");
+        } else {
+            try (InputStream stream = this.getClass().getResourceAsStream(name)) {
+                map.load(stream);
+            } catch (Throwable t) {
+                ExceptionUtils.handleThrowable(t);
+                throw new IllegalArgumentException(t);
+            }
         }
     }
 
