@@ -55,7 +55,7 @@ public final class Extension {
 
 
     public String getExtensionName() {
-        return (this.extensionName);
+        return this.extensionName;
     }
 
     public void setExtensionName(String extensionName) {
@@ -69,7 +69,7 @@ public final class Extension {
     private String implementationURL = null;
 
     public String getImplementationURL() {
-        return (this.implementationURL);
+        return this.implementationURL;
     }
 
     public void setImplementationURL(String implementationURL) {
@@ -84,7 +84,7 @@ public final class Extension {
     private String implementationVendor = null;
 
     public String getImplementationVendor() {
-        return (this.implementationVendor);
+        return this.implementationVendor;
     }
 
     public void setImplementationVendor(String implementationVendor) {
@@ -99,7 +99,7 @@ public final class Extension {
     private String implementationVendorId = null;
 
     public String getImplementationVendorId() {
-        return (this.implementationVendorId);
+        return this.implementationVendorId;
     }
 
     public void setImplementationVendorId(String implementationVendorId) {
@@ -114,7 +114,7 @@ public final class Extension {
     private String implementationVersion = null;
 
     public String getImplementationVersion() {
-        return (this.implementationVersion);
+        return this.implementationVersion;
     }
 
     public void setImplementationVersion(String implementationVersion) {
@@ -129,7 +129,7 @@ public final class Extension {
     private String specificationVendor = null;
 
     public String getSpecificationVendor() {
-        return (this.specificationVendor);
+        return this.specificationVendor;
     }
 
     public void setSpecificationVendor(String specificationVendor) {
@@ -144,7 +144,7 @@ public final class Extension {
     private String specificationVersion = null;
 
     public String getSpecificationVersion() {
-        return (this.specificationVersion);
+        return this.specificationVersion;
     }
 
     public void setSpecificationVersion(String specificationVersion) {
@@ -216,7 +216,6 @@ public final class Extension {
 
     @Override
     public String toString() {
-
         StringBuilder sb = new StringBuilder("Extension[");
         sb.append(extensionName);
         if (implementationURL != null) {
@@ -243,9 +242,8 @@ public final class Extension {
             sb.append(", specificationVersion=");
             sb.append(specificationVersion);
         }
-        sb.append("]");
-        return (sb.toString());
-
+        sb.append(']');
+        return sb.toString();
     }
 
 
