@@ -17,7 +17,6 @@
 package org.apache.catalina.util;
 
 import java.util.ArrayList;
-import java.util.Iterator;
 import java.util.jar.Attributes;
 import java.util.jar.Manifest;
 
@@ -107,9 +106,7 @@ public class ManifestResource {
         if (requiredExtensions == null) {
             return true;
         }
-        Iterator<Extension> it = requiredExtensions.iterator();
-        while (it.hasNext()) {
-            Extension ext = it.next();
+        for (Extension ext : requiredExtensions) {
             if (!ext.isFulfilled()) return false;
         }
         return true;
@@ -117,7 +114,6 @@ public class ManifestResource {
 
     @Override
     public String toString() {
-
         StringBuilder sb = new StringBuilder("ManifestResource[");
         sb.append(resourceName);
 
@@ -132,8 +128,8 @@ public class ManifestResource {
             case WAR : sb.append(", resourceType=WAR"); break;
             case APPLICATION : sb.append(", resourceType=APPLICATION"); break;
         }
-        sb.append("]");
-        return (sb.toString());
+        sb.append(']');
+        return sb.toString();
     }
 
 
