@@ -197,7 +197,9 @@ public class ErrorReportValve extends ValveBase {
             if (throwable != null) {
                 String exceptionMessage = throwable.getMessage();
                 if (exceptionMessage != null && exceptionMessage.length() > 0) {
-                    message = Escape.htmlElementContent((new Scanner(exceptionMessage)).nextLine());
+                    try (Scanner scanner = new Scanner(exceptionMessage)) {
+                        message = Escape.htmlElementContent(scanner.nextLine());
+                    }
                 }
             }
             if (message == null) {
@@ -318,9 +320,7 @@ public class ErrorReportValve extends ValveBase {
                 writer.write(sb.toString());
                 response.finishResponse();
             }
-        } catch (IOException e) {
-            // Ignore
-        } catch (IllegalStateException e) {
+        } catch (IOException | IllegalStateException e) {
             // Ignore
         }
 
