@@ -21,7 +21,6 @@ import java.io.IOException;
 import java.io.InputStream;
 import java.net.URL;
 import java.util.ArrayList;
-import java.util.HashMap;
 import java.util.Map;
 import java.util.Set;
 import java.util.jar.JarEntry;
@@ -37,12 +36,11 @@ public abstract class AbstractArchiveResourceSet extends AbstractResourceSet {
 
     private URL baseUrl;
     private String baseUrlString;
-
     private JarFile archive = null;
-    protected HashMap<String,JarEntry> archiveEntries = null;
+    protected Map<String,JarEntry> archiveEntries = null;
     protected final Object archiveLock = new Object();
     private long archiveUseCount = 0;
-
+    private JarContents jarContents;
 
     protected final void setBaseUrl(URL baseUrl) {
         this.baseUrl = baseUrl;
@@ -110,7 +108,7 @@ public abstract class AbstractArchiveResourceSet extends AbstractResourceSet {
                 }
             }
         }
-        return result.toArray(new String[result.size()]);
+        return result.toArray(new String[0]);
     }
 
     @Override
@@ -172,7 +170,7 @@ public abstract class AbstractArchiveResourceSet extends AbstractResourceSet {
      * @return The archives entries mapped to their names or null if
      *         {@link #getArchiveEntry(String)} should be used.
      */
-    protected abstract HashMap<String,JarEntry> getArchiveEntries(boolean single);
+    protected abstract Map<String,JarEntry> getArchiveEntries(boolean single);
 
 
     /**
@@ -212,6 +210,14 @@ public abstract class AbstractArchiveResourceSet extends AbstractResourceSet {
         String webAppMount = getWebAppMount();
         WebResourceRoot root = getRoot();
 
+        /*
+         * If jarContents reports that this resource definitely does not contain
+         * the path, we can end this method and move on to the next jar.
+         */
+        if (jarContents != null && !jarContents.mightContainResource(path, webAppMount)) {
+            return new EmptyResource(root, path);
+        }
+
         /*
          * Implementation notes
          *
@@ -306,6 +312,10 @@ public abstract class AbstractArchiveResourceSet extends AbstractResourceSet {
         synchronized (archiveLock) {
             if (archive == null) {
                 archive = JreCompat.getInstance().jarFileNewInstance(getBase());
+                WebResourceRoot root = getRoot();
+                if ((root.getContext() != null) && root.getContext().getUseBloomFilterForArchives()) {
+                    jarContents = new JarContents(archive);
+                }
             }
             archiveUseCount++;
             return archive;
@@ -329,6 +339,7 @@ public abstract class AbstractArchiveResourceSet extends AbstractResourceSet {
                 }
                 archive = null;
                 archiveEntries = null;
+                jarContents = null;
             }
         }
     }
