@@ -72,6 +72,8 @@ public class JarWarResource extends AbstractArchiveResource {
                 log.debug(sm.getString("jarResource.getInputStreamFail",
                         getResource().getName(), getBaseUrl()), e);
             }
+            // Ensure jarIs is closed if there is an exception
+            entry = null;
             return null;
         } finally {
             if (entry == null) {
