@@ -94,6 +94,7 @@ public final class Request {
 
     // remote address/host
     private final MessageBytes remoteAddrMB = MessageBytes.newInstance();
+    private final MessageBytes peerAddrMB = MessageBytes.newInstance();
     private final MessageBytes localNameMB = MessageBytes.newInstance();
     private final MessageBytes remoteHostMB = MessageBytes.newInstance();
     private final MessageBytes localAddrMB = MessageBytes.newInstance();
@@ -267,6 +268,10 @@ public final class Request {
         return remoteAddrMB;
     }
 
+    public MessageBytes peerAddr() {
+        return peerAddrMB;
+    }
+
     public MessageBytes remoteHost() {
         return remoteHostMB;
     }
@@ -624,6 +629,7 @@ public final class Request {
         localAddrMB.recycle();
         localNameMB.recycle();
         localPort = -1;
+        peerAddrMB.recycle();
         remoteAddrMB.recycle();
         remoteHostMB.recycle();
         remotePort = -1;
