@@ -17,13 +17,16 @@
 package org.apache.coyote;
 
 import java.util.ArrayList;
+import java.util.List;
+
+import org.apache.tomcat.util.modeler.BaseModelMBean;
 
 /** This can be moved to top level ( eventually with a better name ).
  *  It is currently used only as a JMX artifact, to aggregate the data
  *  collected from each RequestProcessor thread.
  */
-public class RequestGroupInfo {
-    private final ArrayList<RequestInfo> processors = new ArrayList<>();
+public class RequestGroupInfo extends BaseModelMBean {
+    private final List<RequestInfo> processors = new ArrayList<>();
     private long deadMaxTime = 0;
     private long deadProcessingTime = 0;
     private int deadRequestCount = 0;
