@@ -503,6 +503,9 @@ public final class Response {
     }
 
 
+    /**
+     * @return The name of the current encoding
+     */
     public String getCharacterEncoding() {
         return characterEncoding;
     }
@@ -561,8 +564,7 @@ public final class Response {
 
         String ret = contentType;
 
-        if (ret != null
-            && charset != null) {
+        if (ret != null && charset != null) {
             ret = ret + ";charset=" + characterEncoding;
         }
 
