@@ -215,6 +215,12 @@ public abstract class AbstractAjpProtocol<S> extends AbstractProtocol<S> {
     }
 
 
+    @Override
+    public int getDesiredBufferSize() {
+        return getPacketSize() - Constants.SEND_HEAD_LEN;
+    }
+
+
     // --------------------------------------------- SSL is not supported in AJP
 
     @Override
@@ -261,7 +267,7 @@ public abstract class AbstractAjpProtocol<S> extends AbstractProtocol<S> {
         if (getSecretRequired()) {
             String secret = getSecret();
             if (secret == null || secret.length() == 0) {
-                throw new IllegalArgumentException(sm.getString("ajpprotocol.nosecret"));
+                throw new IllegalArgumentException(sm.getString("ajpprotocol.noSecret"));
             }
         }
         super.start();
