@@ -22,6 +22,8 @@ package org.apache.coyote.http2;
  */
 class ConnectionSettingsRemote extends ConnectionSettingsBase<ConnectionException> {
 
+    private static final String ENDPOINT_NAME = "Remote(server->client)";
+
     ConnectionSettingsRemote(String connectionId) {
         super(connectionId);
     }
@@ -31,4 +33,10 @@ class ConnectionSettingsRemote extends ConnectionSettingsBase<ConnectionExceptio
     final void throwException(String msg, Http2Error error) throws ConnectionException {
         throw new ConnectionException(msg, error);
     }
+
+
+    @Override
+    final String getEndpointName() {
+        return ENDPOINT_NAME;
+    }
 }
