@@ -24,8 +24,10 @@ import org.apache.coyote.AbstractProcessor;
 import org.apache.coyote.ActionCode;
 import org.apache.coyote.Adapter;
 import org.apache.coyote.ContainerThreadMarker;
+import org.apache.coyote.ContinueResponseTiming;
 import org.apache.coyote.ErrorState;
 import org.apache.coyote.Request;
+import org.apache.coyote.RequestGroupInfo;
 import org.apache.coyote.Response;
 import org.apache.coyote.http11.filters.GzipOutputFilter;
 import org.apache.juli.logging.Log;
@@ -78,30 +80,31 @@ class StreamProcessor extends AbstractProcessor {
                         if (!getErrorState().isConnectionIoAllowed()) {
                             ConnectionException ce = new ConnectionException(sm.getString(
                                     "streamProcessor.error.connection", stream.getConnectionId(),
-                                    stream.getIdentifier()), Http2Error.INTERNAL_ERROR);
+                                    stream.getIdAsString()), Http2Error.INTERNAL_ERROR);
                             stream.close(ce);
                         } else if (!getErrorState().isIoAllowed()) {
                             StreamException se = stream.getResetException();
                             if (se == null) {
                                 se = new StreamException(sm.getString(
                                         "streamProcessor.error.stream", stream.getConnectionId(),
-                                        stream.getIdentifier()), Http2Error.INTERNAL_ERROR,
+                                        stream.getIdAsString()), Http2Error.INTERNAL_ERROR,
                                         stream.getIdAsInt());
                             }
                             stream.close(se);
                         } else {
-                            // stream.close() will call recycle so only need it here
-                            stream.recycle();
+                            if (!stream.isActive()) {
+                                // stream.close() will call recycle so only need it here
+                                stream.recycle();
+                            }
                         }
                     }
                 } catch (Exception e) {
                     String msg = sm.getString("streamProcessor.error.connection",
-                            stream.getConnectionId(), stream.getIdentifier());
+                            stream.getConnectionId(), stream.getIdAsString());
                     if (log.isDebugEnabled()) {
                         log.debug(msg, e);
                     }
-                    ConnectionException ce = new ConnectionException(msg, Http2Error.INTERNAL_ERROR);
-                    ce.initCause(e);
+                    ConnectionException ce = new ConnectionException(msg, Http2Error.INTERNAL_ERROR, e);
                     stream.close(ce);
                     state = SocketState.CLOSED;
                 } finally {
@@ -209,12 +212,17 @@ class StreamProcessor extends AbstractProcessor {
 
 
     @Override
-    protected final void ack() {
-        if (!response.isCommitted() && request.hasExpectation()) {
-            try {
-                stream.writeAck();
-            } catch (IOException ioe) {
-                setErrorState(ErrorState.CLOSE_CONNECTION_NOW, ioe);
+    protected final void ack(ContinueResponseTiming continueResponseTiming) {
+        // Only try and send the ACK for ALWAYS or if the timing of the request
+        // to send the ACK matches the current configuration.
+        if (continueResponseTiming == ContinueResponseTiming.ALWAYS ||
+                continueResponseTiming == handler.getProtocol().getContinueResponseTimingInternal()) {
+            if (!response.isCommitted() && request.hasExpectation()) {
+                try {
+                    stream.writeAck();
+                } catch (IOException ioe) {
+                    setErrorState(ErrorState.CLOSE_CONNECTION_NOW, ioe);
+                }
             }
         }
     }
@@ -356,13 +364,22 @@ class StreamProcessor extends AbstractProcessor {
 
     @Override
     protected Object getStreamID() {
-        return stream.getIdentifier().toString();
+        return stream.getIdAsString().toString();
     }
 
 
     @Override
     public final void recycle() {
         // StreamProcessor instances are not re-used.
+
+        // Calling removeRequestProcessor even though the RequestProcesser was
+        // never added will add the values from the RequestProcessor to the
+        // running total for the GlobalRequestProcessor
+        RequestGroupInfo global = handler.getProtocol().getGlobal();
+        if (global != null) {
+            global.removeRequestProcessor(request.getRequestProcessor());
+        }
+
         // Clear fields that can be cleared to aid GC and trigger NPEs if this
         // is reused
         setSocketWrapper(null);
@@ -420,7 +437,7 @@ class StreamProcessor extends AbstractProcessor {
     protected final boolean flushBufferedWrite() throws IOException {
         if (log.isDebugEnabled()) {
             log.debug(sm.getString("streamProcessor.flushBufferedWrite.entry",
-                    stream.getConnectionId(), stream.getIdentifier()));
+                    stream.getConnectionId(), stream.getIdAsString()));
         }
         if (stream.flush(false)) {
             // The buffer wasn't fully flushed so re-register the
@@ -464,7 +481,7 @@ class StreamProcessor extends AbstractProcessor {
             // triggered.
             StreamException se = new StreamException(
                     sm.getString("streamProcessor.cancel", stream.getConnectionId(),
-                            stream.getIdentifier()), Http2Error.CANCEL, stream.getIdAsInt());
+                            stream.getIdAsString()), Http2Error.CANCEL, stream.getIdAsInt());
             handler.sendStreamReset(se);
         }
     }
