@@ -5,9 +5,9 @@
  * The ASF licenses this file to You under the Apache License, Version 2.0
  * (the "License"); you may not use this file except in compliance with
  * the License.  You may obtain a copy of the License at
- * 
+ *
  *      http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
  * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
@@ -20,6 +20,8 @@ package org.apache.el.lang;
 import javax.el.ValueExpression;
 import javax.el.VariableMapper;
 
+import org.apache.el.util.MessageFactory;
+
 public class VariableMapperFactory extends VariableMapper {
 
     private final VariableMapper target;
@@ -27,7 +29,7 @@ public class VariableMapperFactory extends VariableMapper {
 
     public VariableMapperFactory(VariableMapper target) {
         if (target == null) {
-            throw new NullPointerException("Target VariableMapper cannot be null");
+            throw new NullPointerException(MessageFactory.get("error.noVariableMapperTarget"));
         }
         this.target = target;
     }
@@ -50,6 +52,6 @@ public class VariableMapperFactory extends VariableMapper {
 
     @Override
     public ValueExpression setVariable(String variable, ValueExpression expression) {
-        throw new UnsupportedOperationException("Cannot Set Variables on Factory");
+        throw new UnsupportedOperationException(MessageFactory.get("error.cannotSetVariables"));
     }
 }
