@@ -16,9 +16,9 @@
  */
 package org.apache.jasper.compiler;
 
+import java.io.BufferedInputStream;
 import java.io.FileNotFoundException;
 import java.io.IOException;
-import java.io.InputStream;
 import java.io.InputStreamReader;
 import java.util.Stack;
 
@@ -238,7 +238,7 @@ class ParserController implements TagConstants {
         } else {
             // Standard syntax
             try (InputStreamReader inStreamReader = JspUtil.getReader(
-                    absFileName, sourceEnc, jar, ctxt, err, skip);) {
+                    absFileName, sourceEnc, jar, ctxt, err, skip)) {
                 JspReader jspReader = new JspReader(ctxt, absFileName,
                         inStreamReader, err);
                 parsedPage = Parser.parse(this, jspReader, parent, isTagFile,
@@ -319,8 +319,8 @@ class ParserController implements TagConstants {
         } else {
             // XML syntax or unknown, (auto)detect encoding ...
             EncodingDetector encodingDetector;
-            try (InputStream inStream = JspUtil.getInputStream(absFileName, jar, ctxt)) {
-                encodingDetector = new EncodingDetector(inStream);
+            try (BufferedInputStream bis = JspUtil.getInputStream(absFileName, jar, ctxt)) {
+                encodingDetector = new EncodingDetector(bis);
             }
 
             sourceEnc = encodingDetector.getEncoding();
@@ -445,8 +445,7 @@ class ParserController implements TagConstants {
             boolean isDirective = jspReader.matches("%@");
             if (isDirective) {
                 jspReader.skipSpaces();
-            }
-            else {
+            } else {
                 isDirective = jspReader.matches("jsp:directive.");
             }
             if (!isDirective) {
