@@ -84,8 +84,6 @@ public class ContextTransaction implements Serializable {
      */
     @Override
     public String toString() {
-        StringBuilder sb = new StringBuilder("Transaction[");
-        sb.append("]");
-        return sb.toString();
+        return "Transaction[]";
     }
 }
