@@ -19,6 +19,8 @@
 package org.apache.tomcat.util.digester;
 
 
+import java.util.HashMap;
+
 import org.apache.tomcat.util.IntrospectionUtils;
 import org.xml.sax.Attributes;
 
@@ -34,6 +36,21 @@ public class SetPropertiesRule extends Rule {
         void endSetPropertiesRule();
     }
 
+    protected final HashMap<String,String> excludes;
+
+    public SetPropertiesRule() {
+        excludes = null;
+    }
+
+    public SetPropertiesRule(String[] exclude) {
+        excludes = new HashMap<>();
+        for (String s : exclude) {
+            if (s != null) {
+                this.excludes.put(s, s);
+            }
+        }
+    }
+
     /**
      * Process the beginning of this element.
      *
@@ -60,10 +77,15 @@ public class SetPropertiesRule extends Rule {
                                    "} Set NULL properties");
             }
         }
+        StringBuilder code = digester.getGeneratedCode();
+        String variableName = null;
+        if (code != null) {
+            variableName = digester.toVariableName(top);
+        }
 
         for (int i = 0; i < attributes.getLength(); i++) {
             String name = attributes.getLocalName(i);
-            if ("".equals(name)) {
+            if (name.isEmpty()) {
                 name = attributes.getQName(i);
             }
             String value = attributes.getValue(i);
@@ -73,17 +95,31 @@ public class SetPropertiesRule extends Rule {
                         "} Setting property '" + name + "' to '" +
                         value + "'");
             }
-            if (!digester.isFakeAttribute(top, name)
-                    && !IntrospectionUtils.setProperty(top, name, value)
-                    && digester.getRulesValidation()) {
-                if (!"optional".equals(name)) {
-                    digester.log.warn(sm.getString("rule.noProperty", digester.match, name, value));
+            if (!digester.isFakeAttribute(top, name) && (excludes == null || !excludes.containsKey(name))) {
+                StringBuilder actualMethod = null;
+                if (code != null) {
+                    actualMethod = new StringBuilder();
+                }
+                if (!IntrospectionUtils.setProperty(top, name, value, true, actualMethod)) {
+                    if (digester.getRulesValidation() && !"optional".equals(name)) {
+                        digester.log.warn(sm.getString("rule.noProperty", digester.match, name, value));
+                    }
+                } else {
+                    if (code != null) {
+                        code.append(variableName).append(".").append(actualMethod).append(';');
+                        code.append(System.lineSeparator());
+                    }
                 }
             }
         }
 
         if (top instanceof Listener) {
             ((Listener) top).endSetPropertiesRule();
+            if (code != null) {
+                code.append("((org.apache.tomcat.util.digester.SetPropertiesRule.Listener) ");
+                code.append(variableName).append(").endSetPropertiesRule();");
+                code.append(System.lineSeparator());
+            }
         }
 
     }
@@ -94,8 +130,6 @@ public class SetPropertiesRule extends Rule {
      */
     @Override
     public String toString() {
-        StringBuilder sb = new StringBuilder("SetPropertiesRule[");
-        sb.append("]");
-        return sb.toString();
+        return "SetPropertiesRule[]";
     }
 }
