@@ -48,7 +48,7 @@ public class SlowQueryReport extends AbstractQueryReport  {
     /**
      * we will be keeping track of query stats on a per pool basis
      */
-    protected static ConcurrentHashMap<String,ConcurrentHashMap<String,QueryStats>> perPoolStats =
+    protected static final ConcurrentHashMap<String,ConcurrentHashMap<String,QueryStats>> perPoolStats =
         new ConcurrentHashMap<>();
     /**
      * the queries that are used for this interceptor.
@@ -104,9 +104,9 @@ public class SlowQueryReport extends AbstractQueryReport  {
             QueryStats qs = this.getQueryStats(sql);
             if (qs != null) {
                 qs.failure(delta, now);
-                if (isLogFailed() && log.isWarnEnabled()) {
-                    log.warn("Failed Query Report SQL="+sql+"; time="+delta+" ms;");
-                }
+            }
+            if (isLogFailed() && log.isWarnEnabled()) {
+                log.warn("Failed Query Report SQL="+sql+"; time="+delta+" ms;");
             }
         }
         return sql;
@@ -215,7 +215,7 @@ public class SlowQueryReport extends AbstractQueryReport  {
 
     /**
      * Sort QueryStats by last invocation time
-     * @param queries
+     * @param queries The queries map
      */
     protected void removeOldest(ConcurrentHashMap<String,QueryStats> queries) {
         ArrayList<QueryStats> list = new ArrayList<>(queries.values());
@@ -479,7 +479,8 @@ public class SlowQueryReport extends AbstractQueryReport  {
      * have never been updated, have a lastInvocation value of {@code 0}
      * which should be handled as the newest possible invocation.
      */
-    private static class QueryStatsComparator implements Comparator<QueryStats> {
+    // Public for unit tests
+    public static class QueryStatsComparator implements Comparator<QueryStats> {
 
         @Override
         public int compare(QueryStats stats1, QueryStats stats2) {
