@@ -23,9 +23,8 @@ import java.util.Arrays;
 import java.util.HashSet;
 import java.util.Set;
 
-import javax.servlet.Filter;
 import javax.servlet.FilterChain;
-import javax.servlet.FilterConfig;
+import javax.servlet.GenericFilter;
 import javax.servlet.HttpConstraintElement;
 import javax.servlet.HttpMethodConstraintElement;
 import javax.servlet.MultipartConfigElement;
@@ -159,12 +158,9 @@ public class TestStandardContext extends TomcatBaseTest {
         }
     }
 
-    public static final class Bug46243Filter implements Filter {
+    public static final class Bug46243Filter extends GenericFilter {
 
-        @Override
-        public void destroy() {
-            // NOOP
-        }
+        private static final long serialVersionUID = 1L;
 
         @Override
         public void doFilter(ServletRequest request, ServletResponse response,
@@ -175,11 +171,10 @@ public class TestStandardContext extends TomcatBaseTest {
         }
 
         @Override
-        public void init(FilterConfig filterConfig) throws ServletException {
-            boolean fail = filterConfig.getInitParameter("fail").equals("true");
+        public void init() throws ServletException {
+            boolean fail = getInitParameter("fail").equals("true");
             if (fail) {
-                throw new ServletException("Init fail (test)",
-                        new ClassNotFoundException());
+                throw new ServletException("Init fail (test)", new ClassNotFoundException());
             }
         }
     }
@@ -271,7 +266,7 @@ public class TestStandardContext extends TomcatBaseTest {
     }
 
     private static class FailingLifecycleListener implements LifecycleListener {
-        private final String failEvent = Lifecycle.CONFIGURE_START_EVENT;
+        private static final String failEvent = Lifecycle.CONFIGURE_START_EVENT;
         private boolean fail = true;
         protected void setFail(boolean fail) {
             this.fail = fail;
@@ -333,12 +328,9 @@ public class TestStandardContext extends TomcatBaseTest {
     }
 
 
-    public static final class Bug49922Filter implements Filter {
+    public static final class Bug49922Filter extends GenericFilter {
 
-        @Override
-        public void destroy() {
-            // NOOP
-        }
+        private static final long serialVersionUID = 1L;
 
         @Override
         public void doFilter(ServletRequest request, ServletResponse response,
@@ -347,11 +339,6 @@ public class TestStandardContext extends TomcatBaseTest {
             response.getWriter().print("Filter");
             chain.doFilter(request, response);
         }
-
-        @Override
-        public void init(FilterConfig filterConfig) throws ServletException {
-            // NOOP
-        }
     }
 
     public static final class Bug49922ForwardServlet extends HttpServlet {
@@ -913,7 +900,7 @@ public class TestStandardContext extends TomcatBaseTest {
                 .isAvailable());
     }
 
-    private class FailingStartupServlet extends HttpServlet {
+    private static class FailingStartupServlet extends HttpServlet {
 
         private static final long serialVersionUID = 1L;
 
