@@ -35,7 +35,6 @@ import org.junit.Assert;
 import org.junit.Test;
 
 import org.apache.catalina.Context;
-import org.apache.catalina.LifecycleListener;
 import org.apache.catalina.startup.Constants;
 import org.apache.catalina.startup.ContextConfig;
 import org.apache.catalina.startup.Tomcat;
@@ -134,7 +133,7 @@ public class TestStandardContextResources extends TomcatBaseTest {
 
         // app dir is relative to server home
         StandardContext ctx = (StandardContext) tomcat.addWebapp(null, "/test",
-                appDir.getAbsolutePath(), (LifecycleListener) absoluteOrderConfig);
+                appDir.getAbsolutePath(), absoluteOrderConfig);
 
         Tomcat.addServlet(ctx, "getresource", new GetResourceServlet());
         ctx.addServletMappingDecoded("/getresource", "getresource");
@@ -156,7 +155,7 @@ public class TestStandardContextResources extends TomcatBaseTest {
         absoluteOrderConfig.swap();
 
         ctx = (StandardContext) tomcat.addWebapp(null, "/test",
-                appDir.getAbsolutePath(), (LifecycleListener) absoluteOrderConfig);
+                appDir.getAbsolutePath(), absoluteOrderConfig);
         Tomcat.addServlet(ctx, "getresource", new GetResourceServlet());
         ctx.addServletMappingDecoded("/getresource", "getresource");
 
