@@ -17,6 +17,7 @@
 package org.apache.catalina.core;
 
 import java.io.IOException;
+import java.util.Locale;
 
 import javax.servlet.ServletException;
 import javax.servlet.ServletRequestEvent;
@@ -29,9 +30,12 @@ import org.junit.Assert;
 import org.junit.Test;
 
 import org.apache.catalina.Context;
+import org.apache.catalina.connector.Connector;
 import org.apache.catalina.connector.Response;
+import org.apache.catalina.startup.ExpectationClient;
 import org.apache.catalina.startup.Tomcat;
 import org.apache.catalina.startup.TomcatBaseTest;
+import org.apache.coyote.ContinueResponseTiming;
 import org.apache.tomcat.util.buf.ByteChunk;
 import org.apache.tomcat.util.descriptor.web.ErrorPage;
 
@@ -83,6 +87,7 @@ public class TestStandardContextValve extends TomcatBaseTest {
         Assert.assertEquals("InitErrorDestroy", trace.toString());
     }
 
+
     @Test
     public void testBug51653b() throws Exception {
         // Set up a container
@@ -133,6 +138,7 @@ public class TestStandardContextValve extends TomcatBaseTest {
         Assert.assertEquals("InitErrorDestroy", trace.toString());
     }
 
+
     private static class Bug51653ErrorTrigger extends HttpServlet {
         private static final long serialVersionUID = 1L;
 
@@ -143,6 +149,7 @@ public class TestStandardContextValve extends TomcatBaseTest {
         }
     }
 
+
     private static class Bug51653ErrorPage extends HttpServlet {
         private static final long serialVersionUID = 1L;
 
@@ -162,6 +169,7 @@ public class TestStandardContextValve extends TomcatBaseTest {
         }
     }
 
+
     private static class Bug51653RequestListener
             implements ServletRequestListener {
 
@@ -182,4 +190,73 @@ public class TestStandardContextValve extends TomcatBaseTest {
         }
 
     }
+
+
+    @Test
+    public void test100ContinueDefault() throws Exception {
+        // The default setting is IMMEDIATELY
+        // This test verifies that we get proper 100 Continue responses
+        // when the continueResponseTiming property is not set
+        test100Continue();
+    }
+
+
+    @Test
+    public void test100ContinueSentImmediately() throws Exception {
+        final Tomcat tomcat = getTomcatInstance();
+
+        final Connector connector = tomcat.getConnector();
+        connector.setProperty("continueResponseTiming", "immediately");
+
+        test100Continue();
+    }
+
+
+    @Test
+    public void test100ContinueSentOnRequestContentRead() throws Exception {
+        final Tomcat tomcat = getTomcatInstance();
+
+        final Connector connector = tomcat.getConnector();
+        final String policyString = ContinueResponseTiming.ON_REQUEST_BODY_READ.toString().toLowerCase(Locale.ENGLISH);
+        connector.setProperty("continueResponseTiming", policyString);
+
+        test100Continue();
+    }
+
+
+    private void test100Continue() throws Exception {
+        // Makes a request that expects a 100 Continue response and verifies
+        // that the 100 Continue response is received. This does not check
+        // that the correct ContinueResponseTiming was used, just
+        // that a 100 Continue response is received. The unit tests for
+        // Request verify that the various settings are correctly implemented.
+
+        final Tomcat tomcat = getTomcatInstance();
+
+        // No file system docBase required
+        final Context ctx = tomcat.addContext("", null);
+
+        Tomcat.addServlet(ctx, "echo", new EchoBodyServlet());
+        ctx.addServletMappingDecoded("/echo", "echo");
+
+        tomcat.start();
+
+        final ExpectationClient client = new ExpectationClient();
+
+        client.setPort(tomcat.getConnector().getLocalPort());
+        // Expected content doesn't end with a CR-LF so if it isn't chunked make
+        // sure the content length is used as reading it line-by-line will fail
+        // since there is no "line".
+        client.setUseContentLength(true);
+
+        client.connect();
+
+        client.doRequestHeaders();
+
+        Assert.assertTrue(client.isResponse100());
+
+        client.doRequestBody();
+        Assert.assertTrue(client.isResponse200());
+        Assert.assertTrue(client.isResponseBodyOK());
+    }
 }
