@@ -23,6 +23,7 @@ import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
 import java.util.Objects;
+import java.util.function.Predicate;
 
 import javax.servlet.ServletException;
 import javax.servlet.http.HttpServlet;
@@ -202,13 +203,13 @@ public class TestRestCsrfPreventionFilter2 extends TomcatBaseTest {
         Map<String, List<String>> reqHeaders = new HashMap<>();
         Map<String, List<String>> respHeaders = new HashMap<>();
 
-        addNonce(reqHeaders, nonce, nonNullPredicate(String.class));
+        addNonce(reqHeaders, nonce, n -> Objects.nonNull(n));
 
         if (useCookie) {
-            addCookies(reqHeaders, notEmptyPredicate());
+            addCookies(reqHeaders, l -> Objects.nonNull(l) && l.size() > 0);
         }
 
-        addCredentials(reqHeaders, credentials, nonNullPredicate(BasicCredentials.class));
+        addCredentials(reqHeaders, credentials, c -> Objects.nonNull(c));
 
         ByteChunk bc = new ByteChunk();
         int rc;
@@ -223,7 +224,7 @@ public class TestRestCsrfPreventionFilter2 extends TomcatBaseTest {
         if (expectedRC == HttpServletResponse.SC_OK) {
             Assert.assertEquals(expectedResponse, bc.toString());
             List<String> newCookies = respHeaders.get(SERVER_COOKIE_HEADER);
-            saveCookies(newCookies, notEmptyPredicate());
+            saveCookies(newCookies, l -> Objects.nonNull(l) && l.size() > 0);
         }
 
         if (!expectCsrfRH) {
@@ -231,7 +232,7 @@ public class TestRestCsrfPreventionFilter2 extends TomcatBaseTest {
         } else {
             List<String> respHeaderValue = respHeaders.get(Constants.CSRF_REST_NONCE_HEADER_NAME);
             Assert.assertNotNull(respHeaderValue);
-            if (nonNull(expectedCsrfRHV)) {
+            if (Objects.nonNull(expectedCsrfRHV)) {
                 Assert.assertTrue(respHeaderValue.contains(expectedCsrfRHV));
             } else {
                 validNonce = respHeaderValue.get(0);
@@ -241,9 +242,7 @@ public class TestRestCsrfPreventionFilter2 extends TomcatBaseTest {
 
     private void saveCookies(List<String> newCookies, Predicate<List<String>> tester) {
         if (tester.test(newCookies)) {
-            for (String newCookie: newCookies) {
-                cookies.add(newCookie.substring(0, newCookie.indexOf(';')));
-            }
+            newCookies.forEach(h -> cookies.add(h.substring(0, h.indexOf(';'))));
         }
     }
 
@@ -361,44 +360,10 @@ public class TestRestCsrfPreventionFilter2 extends TomcatBaseTest {
 
         private String getRequestedPath(HttpServletRequest request) {
             String path = request.getServletPath();
-            if (nonNull(request.getPathInfo())) {
+            if (Objects.nonNull(request.getPathInfo())) {
                 path = path + request.getPathInfo();
             }
             return path;
         }
     }
-
-    private interface Predicate<T> {
-        boolean test(T x);
-    }
-
-    private static boolean nonNull(Object o) {
-        return o != null;
-    }
-
-    /**
-     * @param clazz
-     *            class parameter to enable use of generics
-     * @return a Predicate to test for non null-ness
-     */
-    private static <T> Predicate<T> nonNullPredicate(Class<T> clazz) {
-        return new Predicate<T>() {
-            @Override
-            public boolean test(T x) {
-                return x != null;
-            }
-        };
-    }
-
-    /**
-     * @return a Predicate to check for non emptiness of a List of Strings
-     */
-    private static Predicate<List<String>> notEmptyPredicate() {
-        return new Predicate<List<String>>() {
-            @Override
-            public boolean test(List<String> x) {
-                return x != null && !x.isEmpty();
-            }
-        };
-    }
 }
