@@ -95,6 +95,7 @@ public abstract class SimpleHttpClient {
     private String[] request;
     private boolean useContinue = false;
     private boolean useCookies = true;
+    private boolean useHttp09 = false;
     private int requestPause = 1000;
 
     private String responseLine;
@@ -134,6 +135,10 @@ public abstract class SimpleHttpClient {
         return useCookies;
     }
 
+    public void setUseHttp09(boolean theUseHttp09Flag) {
+        useHttp09 = theUseHttp09Flag;
+    }
+
     public void setRequestPause(int theRequestPause) {
         requestPause = theRequestPause;
     }
@@ -224,8 +229,7 @@ public abstract class SimpleHttpClient {
             if (requestPart != null) {
                 if (first) {
                     first = false;
-                }
-                else {
+                } else {
                     Thread.sleep(requestPause);
                 }
                 writer.write(requestPart);
@@ -242,23 +246,26 @@ public abstract class SimpleHttpClient {
             bodyUriElements.clear();
         }
 
-        // Read the response status line
-        responseLine = readLine();
+        // HTTP 0.9 has neither response line nor headers
+        if (!useHttp09) {
+            // Read the response status line
+            responseLine = readLine();
 
-        // Is a 100 continue response expected?
-        if (useContinue) {
-            if (isResponse100()) {
-                // Skip the blank after the 100 Continue response
-                readLine();
-                // Now get the final response
-                responseLine = readLine();
-            } else {
-                throw new IOException("No 100 Continue response");
+            // Is a 100 continue response expected?
+            if (useContinue) {
+                if (isResponse100()) {
+                    // Skip the blank after the 100 Continue response
+                    readLine();
+                    // Now get the final response
+                    responseLine = readLine();
+                } else {
+                    throw new IOException("No 100 Continue response");
+                }
             }
-        }
 
-        // Put the headers into a map, and process interesting ones
-        processHeaders();
+            // Put the headers into a map, and process interesting ones
+            processHeaders();
+        }
 
         // Read the body, if requested and if one exists
         processBody(wantBody);
@@ -312,8 +319,7 @@ public abstract class SimpleHttpClient {
                 int read = reader.read(body);
                 Assert.assertEquals(contentLength, read);
                 builder.append(body);
-            }
-            else {
+            } else {
                 // not using content length, so just read it line by line
                 String line = null;
                 try {
@@ -356,7 +362,7 @@ public abstract class SimpleHttpClient {
     }
 
     /*
-     * Scan an html body for a given html uri element, starting from the
+     * Scan an HTML body for a given HTML uri element, starting from the
      * given index into the source string. If any are found, simply
      * accumulate them as literal strings, including angle brackets.
      * note: nested elements will not be collected.
