@@ -51,8 +51,8 @@ public class TestGroupChannelSenderConnections extends LoggingBaseTest {
             channels[i].addChannelListener(listeners[i]);
         }
         TesterUtil.addRandomDomain(channels);
-        for (int i = 0; i < channels.length; i++) {
-            channels[i].start(Channel.SND_RX_SEQ|Channel.SND_TX_SEQ);
+        for (ManagedChannel channel : channels) {
+            channel.start(Channel.SND_RX_SEQ | Channel.SND_TX_SEQ);
         }
     }
 
@@ -116,8 +116,8 @@ public class TestGroupChannelSenderConnections extends LoggingBaseTest {
     @Override
     public void tearDown() throws Exception {
         try {
-            for (int i = 0; i < channels.length; i++) {
-                channels[i].stop(Channel.DEFAULT);
+            for (ManagedChannel channel : channels) {
+                channel.stop(Channel.DEFAULT);
             }
         } finally {
             super.tearDown();
