@@ -16,6 +16,7 @@
  */
 package org.apache.coyote.ajp;
 
+import java.nio.charset.StandardCharsets;
 import java.util.ArrayList;
 import java.util.List;
 
@@ -28,6 +29,7 @@ import java.util.List;
 public class TesterAjpMessage extends AjpMessage {
 
     private final List<Header> headers = new ArrayList<>();
+    private final List<Attribute> attributes = new ArrayList<>();
 
 
     public TesterAjpMessage(int packetSize) {
@@ -85,6 +87,16 @@ public class TesterAjpMessage extends AjpMessage {
     }
 
 
+    public void addAttribute(int code, String value) {
+        attributes.add(new Attribute(code, value));
+    }
+
+
+    public void addAttribute(String name, String value) {
+        attributes.add(new Attribute(name, value));
+    }
+
+
     @Override
     public void end() {
         // Add the header count
@@ -94,6 +106,10 @@ public class TesterAjpMessage extends AjpMessage {
             header.append(this);
         }
 
+        for (Attribute attribute : attributes) {
+            attribute.append(this);
+        }
+
         // Terminator
         appendByte(0xFF);
 
@@ -114,6 +130,10 @@ public class TesterAjpMessage extends AjpMessage {
     }
 
 
+    public void appendString(String string) {
+        byte[] bytes = string.getBytes(StandardCharsets.ISO_8859_1);
+        appendBytes(bytes, 0, bytes.length);
+    }
 
 
     private static class Header {
@@ -142,4 +162,33 @@ public class TesterAjpMessage extends AjpMessage {
             message.appendString(value);
         }
     }
+
+
+    private static class Attribute {
+        private final int code;
+        private final String name;
+        private final String value;
+
+        public Attribute(int code, String value) {
+            this.code = code;
+            this.name = null;
+            this.value = value;
+        }
+
+        public Attribute(String name, String value) {
+            this.code = 0;
+            this.name = name;
+            this.value = value;
+        }
+
+        public void append(TesterAjpMessage message) {
+            if (code == 0) {
+                message.appendByte(0x0A);
+                message.appendString(name);
+            } else {
+                message.appendByte(code);
+            }
+            message.appendString(value);
+        }
+    }
 }
