@@ -23,6 +23,7 @@ import java.util.List;
 import java.util.Random;
 
 import org.hamcrest.Description;
+import org.hamcrest.MatcherAssert;
 import org.hamcrest.TypeSafeMatcher;
 
 import org.junit.Assert;
@@ -31,9 +32,45 @@ import org.junit.Test;
 import org.apache.catalina.connector.Connector;
 import org.apache.coyote.http2.HpackEncoder.State;
 import org.apache.tomcat.util.http.MimeHeaders;
+import org.apache.tomcat.util.res.StringManager;
 
 public class TestHttp2Limits extends Http2TestBase {
 
+    private static final StringManager sm = StringManager.getManager(TestHttp2Limits.class);
+
+
+    @Test
+    public void testSettingsOverheadLimits() throws Exception {
+        http2Connect(false);
+
+        for (int i = 0; i < 100; i++) {
+            try {
+                sendSettings(0, false);
+                parser.readFrame(true);
+            } catch (IOException ioe) {
+                // Server closed connection before client has a chance to read
+                // the Goaway frame. Treat this as a pass.
+                return;
+            }
+            String trace = output.getTrace();
+            if (trace.equals("0-Settings-Ack\n")) {
+                // Test continues
+                output.clearTrace();
+            } else if (trace.startsWith("0-Goaway-[1]-[11]-[Connection [")) {
+                // Test passed
+                return;
+            } else {
+                // Test failed
+                Assert.fail("Unexpected output: " + output.getTrace());
+            }
+            Thread.sleep(100);
+        }
+
+        // Test failed
+        Assert.fail("Connection not closed down");
+    }
+
+
     @Test
     public void testHeaderLimits1x128() throws Exception {
         // Well within limits
@@ -247,6 +284,12 @@ public class TestHttp2Limits extends Http2TestBase {
             break;
         }
         case CONNECTION_RESET: {
+            // This message uses i18n and needs to be used in a regular
+            // expression (since we don't know the connection ID). Generate the
+            // string as a regular expression and then replace '[' and ']' with
+            // the escaped values.
+            String limitMessage = sm.getString("http2Parser.headerLimitSize", "\\d++", "3");
+            limitMessage = limitMessage.replace("[", "\\[").replace("]", "\\]");
             // Connection reset. Connection ID will vary so use a pattern
             // On some platform / Connector combinations (e.g. Windows / APR),
             // the TCP connection close will be processed before the client gets
@@ -256,8 +299,8 @@ public class TestHttp2Limits extends Http2TestBase {
             //       above.
             try {
                 parser.readFrame(true);
-                Assert.assertThat(output.getTrace(), RegexMatcher.matchesRegex(
-                        "0-Goaway-\\[1\\]-\\[11\\]-\\[Connection \\[\\d++\\], Stream \\[3\\], .*"));
+                MatcherAssert.assertThat(output.getTrace(), RegexMatcher.matchesRegex(
+                        "0-Goaway-\\[1\\]-\\[11\\]-\\[" + limitMessage + "\\]"));
             } catch (IOException se) {
                 // Expected on some platforms
             }
@@ -405,21 +448,21 @@ public class TestHttp2Limits extends Http2TestBase {
 
 
     @Test
-    public void doTestPostWithTrailerHeadersDefaultLimit() throws Exception{
+    public void testPostWithTrailerHeadersDefaultLimit() throws Exception{
         doTestPostWithTrailerHeaders(Constants.DEFAULT_MAX_TRAILER_COUNT,
                 Constants.DEFAULT_MAX_TRAILER_SIZE, FailureMode.NONE);
     }
 
 
     @Test
-    public void doTestPostWithTrailerHeadersCount0() throws Exception{
+    public void testPostWithTrailerHeadersCount0() throws Exception{
         doTestPostWithTrailerHeaders(0, Constants.DEFAULT_MAX_TRAILER_SIZE,
                 FailureMode.STREAM_RESET);
     }
 
 
     @Test
-    public void doTestPostWithTrailerHeadersSize0() throws Exception{
+    public void testPostWithTrailerHeadersSize0() throws Exception{
         doTestPostWithTrailerHeaders(Constants.DEFAULT_MAX_TRAILER_COUNT, 0,
                 FailureMode.CONNECTION_RESET);
     }
@@ -483,6 +526,13 @@ public class TestHttp2Limits extends Http2TestBase {
             // NIO2 can sometimes send window updates depending timing
             skipWindowSizeFrames();
 
+            // Async I/O can sometimes result in a stream closed reset before
+            // the enhance your calm reset
+            if ("3-RST-[5]\n".equals(output.getTrace())) {
+                output.clearTrace();
+                parser.readFrame(true);
+            }
+
             Assert.assertEquals("3-RST-[11]\n", output.getTrace());
             break;
         }
@@ -490,9 +540,14 @@ public class TestHttp2Limits extends Http2TestBase {
             // NIO2 can sometimes send window updates depending timing
             skipWindowSizeFrames();
 
-            // Connection ID will vary so use a pattern
-            Assert.assertThat(output.getTrace(), RegexMatcher.matchesRegex(
-                    "0-Goaway-\\[3\\]-\\[11\\]-\\[Connection \\[\\d++\\], Stream \\[3\\], .*"));
+            // This message uses i18n and needs to be used in a regular
+            // expression (since we don't know the connection ID). Generate the
+            // string as a regular expression and then replace '[' and ']' with
+            // the escaped values.
+            String limitMessage = sm.getString("http2Parser.headerLimitSize", "\\d++", "3");
+            limitMessage = limitMessage.replace("[", "\\[").replace("]", "\\]");
+            MatcherAssert.assertThat(output.getTrace(), RegexMatcher.matchesRegex(
+                    "0-Goaway-\\[3\\]-\\[11\\]-\\[" + limitMessage + "\\]"));
             break;
         }
         }
