@@ -18,6 +18,7 @@ package org.apache.coyote.http2;
 
 import java.io.File;
 import java.io.IOException;
+import java.io.OutputStream;
 import java.io.PrintWriter;
 import java.nio.ByteBuffer;
 import java.util.ArrayList;
@@ -34,7 +35,9 @@ import org.junit.Test;
 
 import org.apache.catalina.Context;
 import org.apache.catalina.Wrapper;
+import org.apache.catalina.connector.Connector;
 import org.apache.catalina.startup.Tomcat;
+import org.apache.coyote.UpgradeProtocol;
 import org.apache.tomcat.util.compat.JrePlatform;
 import org.apache.tomcat.util.http.FastHttpDateFormat;
 
@@ -223,4 +226,87 @@ public class TestStreamProcessor extends Http2TestBase {
             });
         }
     }
+
+
+    @Test
+    public void testCompression() throws Exception {
+        enableHttp2();
+
+        Tomcat tomcat = getTomcatInstance();
+
+        Context ctxt = tomcat.addContext("", null);
+        Tomcat.addServlet(ctxt, "simple", new SimpleServlet());
+        ctxt.addServletMappingDecoded("/simple", "simple");
+        Tomcat.addServlet(ctxt, "compression", new CompressionServlet());
+        ctxt.addServletMappingDecoded("/compression", "compression");
+
+        // Enable compression
+        Connector connector = tomcat.getConnector();
+
+        tomcat.start();
+
+        enableHttp2();
+        for (UpgradeProtocol protocol : connector.findUpgradeProtocols()) {
+            if (protocol instanceof Http2Protocol) {
+                ((Http2Protocol) protocol).setCompression("on");
+            }
+        }
+        openClientConnection();
+        doHttpUpgrade();
+        sendClientPreface();
+        validateHttp2InitialResponse();
+
+
+        byte[] frameHeader = new byte[9];
+        ByteBuffer headersPayload = ByteBuffer.allocate(128);
+
+        List<Header> headers = new ArrayList<>(3);
+        headers.add(new Header(":method", "GET"));
+        headers.add(new Header(":scheme", "http"));
+        headers.add(new Header(":path", "/compression"));
+        headers.add(new Header(":authority", "localhost:" + getPort()));
+        headers.add(new Header("accept-encoding", "gzip"));
+
+        buildGetRequest(frameHeader, headersPayload, null, headers, 3);
+
+        writeFrame(frameHeader, headersPayload);
+
+        readSimpleGetResponse();
+
+        Assert.assertEquals(
+                "3-HeadersStart\n" +
+                "3-Header-[:status]-[200]\n" +
+                "3-Header-[vary]-[accept-encoding]\n" +
+                "3-Header-[content-encoding]-[gzip]\n" +
+                "3-Header-[content-type]-[text/plain;charset=UTF-8]\n" +
+                "3-Header-[date]-[Wed, 11 Nov 2015 19:18:42 GMT]\n" +
+                "3-HeadersEnd\n" +
+                "3-Body-97\n" +
+                "3-EndOfStream\n", output.getTrace());
+    }
+
+
+    private static class CompressionServlet extends HttpServlet {
+
+        private static final long serialVersionUID = 1L;
+
+        @Override
+        protected void doGet(HttpServletRequest req, HttpServletResponse resp)
+                throws ServletException, IOException {
+            // Generate content type that is compressible
+            resp.setContentType("text/plain");
+            resp.setCharacterEncoding("UTF-8");
+
+            // Make ir large enough to trigger compression
+            int count = 64 * 1024;
+
+            // One bytes per entry
+            resp.setContentLengthLong(count);
+
+            OutputStream os = resp.getOutputStream();
+            for (int i = 0; i < count; i++) {
+                os.write('X');
+            }
+        }
+    }
 }
