@@ -55,15 +55,13 @@ public class TestTokenList {
 
     @Test
     public void testEmptyString() throws IOException {
-        Set<String> s = Collections.emptySet();
-        doTestVary("", s, false);
+        doTestVary("", Collections.emptySet(), false);
     }
 
 
     @Test
     public void testSingleInvalid() throws IOException {
-        Set<String> s = Collections.emptySet();
-        doTestVary("{{{", s, false);
+        doTestVary("{{{", Collections.emptySet(), false);
     }
 
 
