@@ -78,12 +78,16 @@ public class TestSsl extends TomcatBaseTest {
                 TesterSupport.getLastClientAuthRequestedIssuerCount() == 0);
     }
 
+    private static final int POST_DATA_SIZE = 16 * 1024 * 1024;
+
     @Test
     public void testPost() throws Exception {
         SocketFactory socketFactory = TesterSupport.configureClientSsl();
 
         Tomcat tomcat = getTomcatInstance();
         TesterSupport.initSsl(tomcat);
+        // Increase timeout as default (3s) can be too low for some CI systems
+        Assert.assertTrue(tomcat.getConnector().setProperty("connectionTimeout", "20000"));
 
         Context ctxt = tomcat.addContext("", null);
         Tomcat.addServlet(ctxt, "post", new SimplePostServlet());
@@ -102,7 +106,7 @@ public class TestSsl extends TomcatBaseTest {
 
                         OutputStream os = socket.getOutputStream();
 
-                        byte[] bytes = new byte[16 * 1024 * 1024]; // 16MB
+                        byte[] bytes = new byte[POST_DATA_SIZE]; // 16MB
                         Arrays.fill(bytes, (byte) 1);
 
                         os.write("POST /post HTTP/1.1\r\n".getBytes());
@@ -121,7 +125,13 @@ public class TestSsl extends TomcatBaseTest {
                         byte[] endOfHeaders = "\r\n\r\n".getBytes();
                         int found = 0;
                         while (found != endOfHeaders.length) {
-                            if (is.read() == endOfHeaders[found]) {
+                            int c = is.read();
+                            if (c == -1) {
+                                // EOF
+                                System.err.println("Unexpected EOF");
+                                errorCount.incrementAndGet();
+                                break;
+                            } else if (c == endOfHeaders[found]) {
                                 found++;
                             } else {
                                 found = 0;
@@ -131,8 +141,8 @@ public class TestSsl extends TomcatBaseTest {
                         for (int i = 0; i < bytes.length; i++) {
                             int read = is.read();
                             if (bytes[i] != read) {
-                                System.err.print("Byte in position [" + i + "] had value [" + read +
-                                        "] rather than " + Byte.toString(bytes[i]));
+                                System.err.println("Byte in position [" + i + "] had value [" + read +
+                                        "] rather than [" + Byte.toString(bytes[i]) + "]");
                                 errorCount.incrementAndGet();
                                 break;
                             }
@@ -248,7 +258,11 @@ public class TestSsl extends TomcatBaseTest {
         char[] endOfHeaders ="\r\n\r\n".toCharArray();
         int found = 0;
         while (found != endOfHeaders.length) {
-            if (r.read() == endOfHeaders[found]) {
+            int c = r.read();
+            if (c == -1) {
+                // EOF
+                Assert.fail("Unexpected EOF");
+            } else if (c == endOfHeaders[found]) {
                 found++;
             } else {
                 found = 0;
@@ -277,13 +291,13 @@ public class TestSsl extends TomcatBaseTest {
         }
     }
 
-    public class SimplePostServlet extends HttpServlet {
+    public static class SimplePostServlet extends HttpServlet {
 
         private static final long serialVersionUID = 1L;
 
         @Override
         protected void doPost(HttpServletRequest req, HttpServletResponse resp) throws ServletException, IOException {
-            ByteArrayOutputStream baos = new ByteArrayOutputStream();
+            ByteArrayOutputStream baos = new ByteArrayOutputStream(POST_DATA_SIZE);
             byte[] in = new byte[1500];
             InputStream input = req.getInputStream();
             while (true) {
@@ -295,6 +309,7 @@ public class TestSsl extends TomcatBaseTest {
                 }
             }
             byte[] out = baos.toByteArray();
+            // Set the content-length to avoid having to parse chunked
             resp.setContentLength(out.length);
             resp.getOutputStream().write(out);
         }
